from .utils import cmd_exists, peerflix
import sys
import colorful
from .argument_parser import Parser
from .ezflix import Ezflix
from prettytable import PrettyTable

parser = Parser()
args = parser.parse()

media_player = args.media_player

if not cmd_exists('peerflix'):
    sys.exit('This program requires Peerflix. https://github.com/mafintosh/peerflix')

if not cmd_exists('mpv') and args.media_player == 'mpv':
    media_player = 'vlc'

if not args.query:
    sys.exit(colorful.red("Search query not valid."))

def main():
    ezflix = Ezflix(query=args.query,
                    media_type=args.media_type,
                    limit=args.limit,
                    sort_by=args.sort_by,
                    sort_order=args.sort_order,
                    quality=args.quality,
                    minimum_rating=args.minimum_rating,
                    language=args.language
                    )

    torrents = ezflix.get_torrents()

    if torrents is None:
        sys.exit(colorful.red('No results found.'))

    if args.latest:

        latest = torrents[0]
        file_path = ''

        if args.subtitles:
            file_path = ezflix.find_subtitles(latest['title'])

        print("Playing " + latest['title'])

        peerflix(latest['magnet'], media_player, args.media_type, args.subtitles, args.remove, file_path)

        sys.exit()

    row = PrettyTable()
    row.field_names = ["Id", "Torrent"]
    row.align = 'l'
    for result in torrents:
        row.add_row([result['id'], result['title']])

    print(row)

    print(colorful.bold("Make selection: (Enter quit to close the program)"))

    while True:
        read = input()

        if read == 'quit':
            sys.exit()

        try:
            int_val = int(read)
        except ValueError:
            print(colorful.red('Invalid selection.'))
            continue

        magnet = ezflix.get_magnet(int_val)

        if not magnet:
            print(colorful.red('Invalid selection.'))
            continue

        print("Playing " + magnet['title'])

        file_path = ''

        if args.subtitles:
            file_path = ezflix.find_subtitles(magnet['title'])

        peerflix(magnet['magnet'], media_player, args.media_type, args.subtitles, args.remove, file_path)


if __name__ == '__main__':
    try:
        main()
    except KeyboardInterrupt:
        sys.exit()



import requests
from bs4 import BeautifulSoup
import sys


def eztv(q, limit):
    limit = int(limit)
    url = 'https://eztv.ag/search/' + q
    req = requests.get(url)
    soup = BeautifulSoup(req.text, 'html.parser')
    magnets = soup.find_all('a', {'class': 'magnet'}, href=True)

    if magnets is None:
        sys.exit('No results found')

    arr, count = [], 1
    for magnet in magnets:
        
        if count == limit + 1:
            break

        if q.lower().strip()[0] in magnet['title'].lower():
            arr.append({'id': count, 'title': magnet['title'][:-12], 'magnet': magnet['href']})
        
        count += 1
    
    return arr



import requests


def yts(q, limit=20, minimum_rating=4, quality='720p', sort_by='seeds', sort_order='desc'):
    params = {
        'query_term': q,
        'sort_by': sort_by,
        'sort_order': sort_order,
        'limit': limit,
        'quality': quality,
        'minimum_rating': minimum_rating

    }
    req = requests.get('https://yts.ag/api/v2/list_movies.json', params=params)

    if req.status_code == 200:
        req = req.json()
        if req['status'] == 'ok':
            if req['data']['movie_count'] > 0:
                arr, count = [], 1
                for r in req['data']['movies']:
                    for torrent in r['torrents']:
                        title = '%s (%s) (%s)' % (r['title'], r['year'], torrent['quality'])
                        arr.append({'id': count,
                                    'title': title,
                                    'magnet': torrent['url']})
                        count += 1
                return arr
